@@ -23,18 +23,18 @@ static const char sccsid[] = "@(#)dclock.c	5.00 2000/11/01 xlockmore";
  *
  * Revision History:
  * 03-Dec-2005: Added a binary clock display, after seeing the binary clock
- *              at thinkgeek. Petey (petey_leinonen@yahoo.com.au)
+ *              at thinkgeek. Petey (petey_leinonen AT yahoo.com.au)
  * 01-Mar-2005: Added 24 hour clock (alex(at)shark-linux(dot)de)
  * 01-Nov-2000: Allocation checks
  * 07-May-1999: New "savers" added for y2k and second millennium countdowns.
- *              Tom Schmidt <tschmidt@micron.com>
+ *              Tom Schmidt <tschmidt AT micron.com>
  * 04-Dec-1998: New "savers" added for hiv, veg, and lab.
  *              hiv one due to Kenneth Stailey <kstailey@disclosure.com>
  * 10-Aug-1998: Population Explosion and Tropical Forest Countdown stuff
  *              I tried to get precise numbers but they may be off a few
  *              percent.  Whether or not, its still pretty scary IMHO.
  *              Although I am a US citizen... I have the default for area in
- *              metric.  David Bagley <bagleyd@tux.org>
+ *              metric.  David Bagley <bagleyd AT verizon.net>
  * 10-May-1997: Compatible with xscreensaver
  * 29-Aug-1995: Written.
  */
@@ -998,6 +998,13 @@ init_dclock(ModeInfo * mi)
 #if (!defined(MODE_dclock_y2k) && !defined(MODE_dclock_millennium) && !defined(MODE_dclock_mayan))
 #define NUM_DCLOCK_MODES 9
 #endif
+#ifdef WIN32
+	if (NRAND(2)) {
+				dp->led = True;
+	} else {
+				dp->binary = True;
+	}
+#else
 	if (!(message && *message)) {
 	    if (MI_IS_FULLRANDOM(mi)) {
 		switch (NRAND(NUM_DCLOCK_MODES)) {
@@ -1071,6 +1078,7 @@ init_dclock(ModeInfo * mi)
 		dp->mayan = mayan;
 	    }
 	}
+#endif
 
 	if (mode_font == None) {
 #ifdef USE_MB
@@ -1107,9 +1115,9 @@ init_dclock(ModeInfo * mi)
 	timeNow = seconds();
 	timeLocal = timeNow + dp->tzoffset;
 	if (dp->led) {
-		dp->lines = 1;
-		dp->text_descent = 0;
-		dp->text_ascent = 0;
+		dp->lines = 2;
+		/*dp->text_descent = 0;
+		dp->text_ascent = 0;*/
 		for (i = 0; i < 4; i++) {
 			if (parallelogramUnit[i].x == 1)
 				dp->parallelogram[i].x = (short) (LED_XS *
@@ -1132,7 +1140,7 @@ init_dclock(ModeInfo * mi)
 		dp->text_width = (short) (6 * (LED_XS + LED_WIDTH + LED_INC) +
 			2 * (LED_WIDTH + LED_INC) + LED_XS * LED_LEAN - LED_INC);
 		dp->text_height = (short) (LED_YS + LED_WIDTH + LED_INC);
-		dp->maxy = dp->height - dp->text_height;
+		dp->maxy = dp->height - (dp->lines - 1) * dp->text_height;
 		if (dp->maxy == 0)
 			dp->clocky = 0;
 		else if (dp->maxy < 0)
